<?php

declare(strict_types=1);

namespace FiloBlu\Design\Block;

use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\ObjectManagerInterface;
use Magento\Framework\Serialize\Serializer\Json;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;

/**
 * @class Customer
 * @package FiloBlu\Design\Block
 */
class Customer extends Template
{

    /**
     * @var Json|null
     */
    private $jsonSerializer;

    /**
     * @param Context $context
     * @param ObjectManagerInterface $objectManager
     * @param array $data
     */
    public function __construct(
        Context                $context,
        ObjectManagerInterface $objectManager,
        array                  $data = []
    ) {
        parent::__construct($context, $data);

        if (class_exists(\Magento\Framework\Serialize\Serializer\Json::class)) {
            $this->jsonSerializer = $objectManager->create(\Magento\Framework\Serialize\Serializer\Json::class);
        }
    }

    /**
     * @return int
     * @throws NoSuchEntityException
     */
    public function getWebsiteId()
    {
        return $this->_storeManager->getStore()->getWebsiteId();
    }

    /**
     * @param array $array
     * @return bool|string
     */
    public function jsonEncode(array $array)
    {
        if (isset($this->jsonSerializer)) {
            return $this->jsonSerializer->serialize($array);
        }

        return json_encode($array);
    }
}
