/**
 * Copyright © 2013-2017 Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

define([
    'underscore',
    'Magento_Ui/js/form/element/abstract',
    'mageUtils',
    'Magento_Ui/js/lib/validation/validator',
    'jquery',
    'jquery/ui',
    'jquery/validate',
    'mage/translate',
    'mage/cookies',
    'intlTelInputUtils',
    'intlTelInput'
], function(_, Abstract, utils, validator, $) {
    'use strict';

    return Abstract.extend({
        /**
         * Handler function which is supposed to be invoked when
         * file input element has been rendered.
         *
         * @param {HTMLInputElement} fileInput
         */
        onElementRender: function(input) {
            if (window.checkoutConfig.intlTelInput) {
                var currentInput = $(input);

                /*fix for not translated countries*/
                if (window.checkoutConfig.intlTelInput.translationFix) {
                    var countryData = currentInput.intlTelInput.getCountryData();
                    for (var i = 0; i < countryData.length; i++) {
                        var country = countryData[i];
                        country.name = country.name.replace(/ \(.*\)/,"");
                    }
                }

                if (window.checkoutConfig.intlTelInput.geolocation) {
                    var geoip_cookie = $.cookie('filoblu_geoip_country');
                    if (geoip_cookie) {
                        currentInput.intlTelInput({
                            initialCountry: geoip_cookie,
                            utilsScript: window.checkoutConfig.intlTelInput.utilsScriptUrl
                        });
                    } else {
                        var baseURL = window.checkoutConfig.intlTelInput.baseURL;
                        $.ajax({
                            url: baseURL + "fbdesign_geolocation/index/geolocation",
                            dataType: 'json',
                            cache: false
                        }).done(function(data) {
                            currentInput.intlTelInput({
                                initialCountry: data.country_code,
                                utilsScript: window.checkoutConfig.intlTelInput.utilsScriptUrl
                            });
                        }).fail(function() {
                            currentInput.intlTelInput({
                                initialCountry: window.checkoutConfig.intlTelInput.defaultCountry,
                                utilsScript: window.checkoutConfig.intlTelInput.utilsScriptUrl
                            });
                        });
                    }
                } else {
                    currentInput.intlTelInput({
                        initialCountry: window.checkoutConfig.intlTelInput.defaultCountry,
                        utilsScript: window.checkoutConfig.intlTelInput.utilsScriptUrl
                    });
                }

                if (window.checkoutConfig.intlTelInput.validation) {

                    currentInput.blur(function(event) {
                        var that = $(this);

                        if ($.trim(that.val())) {
                            currentInput.val(that.intlTelInput("getNumber")).change();
                        }
                    });
                }
            }
        },

        validate: function() {
            var value = this.value(),
                result = validator(this.validation, value, this.validationParams),
                message = !this.disabled() && this.visible() ? result.message : '',
                isValid = this.disabled() || !this.visible() || result.passed;

            this.error(message);
            this.bubble('error', message);

            //TODO: Implement proper result propagation for form
            if (!isValid) {
                this.source.set('params.invalid', true);
            }

            if (isValid && window.checkoutConfig.intlTelInput && window.checkoutConfig.intlTelInput.validation) {
                var inp = $("<input type='tel' value='" + value + "' />");
                if (value == "") {
                    isValid = true;
                }
                else {
                    inp.intlTelInput({
                        utilsScript: window.checkoutConfig.intlTelInput.utilsScriptUrl
                    });
                    isValid = this.disabled() || !this.visible() || inp.intlTelInput("isValidNumber");
                }

                if (!isValid) {
                    message = $.mage.__('Please enter a valid number.');
                    this.error(message);
                    this.bubble('error', message);
                    this.source.set('params.invalid', true);
                }
            }

            return {
                valid: isValid,
                target: this
            };
        },

        initConfig: function() {

            var uid = utils.uniqueid(),
                name,
                valueUpdate,
                scope;

            this._super();

            scope = this.dataScope;
            name = scope.split('.').slice(1);

            valueUpdate = this.showFallbackReset ? 'afterkeydown' : this.valueUpdate;

            _.extend(this, {
                uid: uid,
                noticeId: 'notice-' + uid,
                inputName: utils.serializeName(name.join('.')),
                valueUpdate: valueUpdate,
                onElementRender: this.onElementRender
            });

            return this;
        }
    });
});
